mosaicsFit( object, ... )
"mosaicsFit"( object, analysisType="automatic", bgEst="rMOM", k=3, meanThres=NA, s=2, d=0.25, trans="power", truncProb=0.999, parallel=FALSE, nCore=8 )BinData,
bin-level ChIP-seq data imported using method readBins. analysisType="automatic",
this method tries to make the best guess for analysisType,
based on the data provided. bgEst="automatic",
this method tries to make the best guess for bgEst,
based on the data provided.
Default is bgEst="rMOM". analysisType="TS" and 0 for analysisType="OS".
Not relevant when analysisType="IO". analysisType="TS". Default is 2. analysisType="TS" or analysisType="IO".
Default is 0.25. analysisType="IO".
Default is trans="power". analysisType="IO". "parallel" package?
Possible values are TRUE (utilize multiple CPUs)
or FALSE (do not utilize multiple CPUs).
Default is FALSE (do not utilize multiple CPUs). mosaicsFit.MosaicsFit class object.
type=c("chip", "input") or type=c("chip", "input", "N")
was used in method readBins),
only two-sample analysis without using mappability and GC content
(analysisType="IO") is allowed.
If matched control data is available
with mappability score, GC content score, and sequence ambiguity score,
(i.e., type=c("chip", "input", "M", "GC", "N") was used in method readBins),
user can do all of three analysis types
(analysisType="OS", analysisType="TS", or analysisType="IO").
If there is no data for matched control sample
(i.e., type=c("chip", "M", "GC", "N") was used in method readBins),
only one-sample analysis (analysisType="OS") is permitted.Parallel computing can be utilized for faster computing
if parallel=TRUE and parallel package is loaded.
nCore determines number of CPUs used for parallel computing.
meanThres, s, d, trans, and truncProb are
the tuning parameters for estimating background distribution.
The vignette and Kuan et al. (2011) provide further details about these tuning parameters.
Please do not try different value for k argument.
Chung, D, Zhang Q, and Keles S (2014), "MOSAiCS-HMM: A model-based approach for detecting regions of histone modifications from ChIP-seq data", Datta S and Nettleton D (eds.), Statistical Analysis of Next Generation Sequencing Data, Springer.
readBins, mosaicsFitHMM, MosaicsFit.
## Not run:
# library(mosaicsExample)
# data(exampleBinData)
# exampleFit <- mosaicsFit( exampleBinData, analysisType="IO" )
# ## End(Not run)
Run the code above in your browser using DataLab