Learn R Programming

mosaics (version 2.10.0)

mosaicsPeak: Call peaks using fitted MOSAiCS model

Description

Call peaks using MosaicsFit class object, which is a fitted MOSAiCS model.

Usage

mosaicsPeak( object, ... ) "mosaicsPeak"( object, signalModel="2S", FDR=0.05, binsize=NA, maxgap=200, minsize=50, thres=10 )

Arguments

object
Object of class MosaicsFit, a fitted MOSAiCS model obtained using function mosaicsFit.
signalModel
Signal model. Possible values are "1S" (one-signal-component model) and "2S" (two-signal-component model). Default is "2S".
FDR
False discovery rate. Default is 0.05.
binsize
Size of each bin. Value should be positive integer. If binsize=NA, mosaicsPeak function calcuates the value from data. Default is NA.
maxgap
Initial nearby peaks are merged if the distance (in bp) between them is less than maxgap. Default is 200.
minsize
An initial peak is removed if its width is narrower than minsize. Default is 50.
thres
A bin within initial peak is removed if its ChIP tag counts are less than thres. Default is 10.
...
Other parameters to be passed through to generic mosaicsPeak.

Value

Construct MosaicsPeak class object.

Details

mosaicsPeak is developed to identify narrow peaks such as transcription factor binding sites. If you are interested in identifying broad peaks such as histone modifications, please use mosaicsFitHMM and mosaicsPeakHMM instead of mosaicsPeak.

When peaks are called, proper signal model needs to be specified. The optimal choice for the number of signal components depends on the characteristics of ChIP-seq data. In order to support users in the choice of optimal signal model, Bayesian Information Criterion (BIC) values and Goodness of Fit (GOF) plot are provided for the fitted MOSAiCS model. BIC values and GOF plot can be obtained by applying show and plot methods, respectively, to the MosaicsFit class object, which is a fitted MOSAiCS model.

maxgap, minsize, and thres are for refining initial peaks called using specified signalModel and FDR. If you use a bin size shorter than the average fragment length of the experiment, we recommend to set maxgap to the average fragment length and minsize to the bin size. If you set the bin size to the average fragment length or if bin size is larger than the average fragment length, set maxgap to the average fragment length and minsize to a value smaller than the average fragment length. See the vignette for further details.

References

Kuan, PF, D Chung, G Pan, JA Thomson, R Stewart, and S Keles (2011), "A Statistical Framework for the Analysis of ChIP-Seq Data", Journal of the American Statistical Association, Vol. 106, pp. 891-903.

Chung, D, Zhang Q, and Keles S (2014), "MOSAiCS-HMM: A model-based approach for detecting regions of histone modifications from ChIP-seq data", Datta S and Nettleton D (eds.), Statistical Analysis of Next Generation Sequencing Data, Springer.

See Also

mosaicsFit, MosaicsPeak, MosaicsFit.

Examples

Run this code
## Not run: 
# library(mosaicsExample)
# data(exampleBinData)
# exampleFit <- mosaicsFit( exampleBinData, analysisType="IO" )
# examplePeak <- mosaicsPeak( exampleFit, signalModel = "2S", FDR = 0.05 )
# ## End(Not run)

Run the code above in your browser using DataLab