MosaicsFit class object, which is a fitted MOSAiCS model.
mosaicsPeak( object, ... )
"mosaicsPeak"( object, signalModel="2S", FDR=0.05, binsize=NA, maxgap=200, minsize=50, thres=10 )MosaicsFit,
a fitted MOSAiCS model obtained using function mosaicsFit. binsize=NA, mosaicsPeak function calcuates the value from data.
Default is NA. maxgap. Default is 200. minsize. Default is 50. thres. Default is 10. mosaicsPeak.MosaicsPeak class object.
mosaicsPeak is developed to identify narrow peaks such as transcription factor binding sites.
If you are interested in identifying broad peaks such as histone modifications,
please use mosaicsFitHMM and mosaicsPeakHMM instead of mosaicsPeak.When peaks are called, proper signal model needs to be specified.
The optimal choice for the number of signal components depends on the characteristics of ChIP-seq data.
In order to support users in the choice of optimal signal model,
Bayesian Information Criterion (BIC) values and Goodness of Fit (GOF) plot are provided
for the fitted MOSAiCS model.
BIC values and GOF plot can be obtained by applying show and plot methods,
respectively, to the MosaicsFit class object, which is a fitted MOSAiCS model.
maxgap, minsize, and thres are for refining initial peaks called
using specified signalModel and FDR.
If you use a bin size shorter than the average fragment length of the experiment,
we recommend to set maxgap to the average fragment length
and minsize to the bin size.
If you set the bin size to the average fragment length or if bin size is larger than the average fragment length,
set maxgap to the average fragment length and
minsize to a value smaller than the average fragment length. See the vignette for further details.
Chung, D, Zhang Q, and Keles S (2014), "MOSAiCS-HMM: A model-based approach for detecting regions of histone modifications from ChIP-seq data", Datta S and Nettleton D (eds.), Statistical Analysis of Next Generation Sequencing Data, Springer.
mosaicsFit,
MosaicsPeak, MosaicsFit.
## Not run:
# library(mosaicsExample)
# data(exampleBinData)
# exampleFit <- mosaicsFit( exampleBinData, analysisType="IO" )
# examplePeak <- mosaicsPeak( exampleFit, signalModel = "2S", FDR = 0.05 )
# ## End(Not run)
Run the code above in your browser using DataLab